@@ -11,7 +11,7 @@ from django.template import Library, Node, TemplateSyntaxError
 from analytical.utils import is_internal_ip, disable_html, get_required_setting
 
 
-ACCOUNT_NUMBER_RE = re.compile(r'^\d{7}$')
+ACCOUNT_NUMBER_RE = re.compile(r'^\d+$')
 SETUP_CODE = """<script src="//cdn.optimizely.com/js/%(account_number)s.js"></script>"""
 
 
@@ -36,7 +36,7 @@ class OptimizelyNode(Node):
     def __init__(self):
         self.account_number = get_required_setting(
                 'OPTIMIZELY_ACCOUNT_NUMBER', ACCOUNT_NUMBER_RE,
-                "must be a string containing an seven-digit number")
+                "must be a string looking like 'XXXXXXX'")
 
     def render(self, context):
         html = SETUP_CODE % {'account_number': self.account_number}
